CREATE TABLE IF NOT EXISTS posebni_cjenik (
  kodPoslovnice      VARCHAR(5) NOT NULL,
  oznakaCjenika      VARCHAR(13) DEFAULT " ",
  kodPartnera        VARCHAR(13) DEFAULT " ",
  kodRobe            VARCHAR(16) NOT NULL,
  vrstaProdaje       CHAR(1) DEFAULT "0",
  cijena             DECIMAL(11,3)  NOT NULL,
  datumOtvaranja     DATETIME DEFAULT NULL,
  datumIzmjene       DATETIME DEFAULT 0,
  tkoJeIzmjenio      VARCHAR(40) DEFAULT " ", 
  PRIMARY KEY (kodPoslovnice, oznakaCjenika, kodPartnera, kodRobe, vrstaProdaje) 
 );
-- Posebni cjenik cjene robe se vade iz posebnog cjenika a ne iz maticna_robe
-- Slučaj 1 Dinamic posebne cijene za pojedine prodavaone
-- npr. prodavaona 204 ima za akumulatore posebne cijene ili za svu robu
--    sve šifre akumulatora se ubace sa svojim posebnim cjenama 
--    za svu ostalu robu koje nema u posebnom cjeniku, cijene se vade iz maticna_robe 
--    na poslovnicama je za 204 polje posebniCjenik popunjeno sa true što je znak da program vadi cijene 
--    iz posebnog cjenika za tu prodavaonu(ako ih nađe, ako ih ne nađe vadi cijene iz maticna-robe)
--    oznakaCjenika i kodPartnera su popunjeni sa jedan space(default)
--    ako je prodavaona 0 posebni cjenik se primjenjuje za cijelu firmu(sve poslovnice)
-- Slučaj 2 Chaky,PanexAgm 
--   posebni cjeniki se primjenjuju za pojedine kupce ili skupine kupaca ili posebne vste robe 
--   pr. c1 maloprodajni cjenik, c3 konsignacijski(VP=2) cjenik, c3 cjenik za Bat,Jesenović,Fiac, c5 cjenik za mercator šifra 806
--   c13  cjenik za reklamirane akumulatore i slično.
--   u ovom slučaju koristi se oznakaCjenika
--   kod Panex-Agm može postojati konsignacijski cjenik po poslovnim partnerima (vp=2)
--   ako je kodPartnera popunjen cjenik se primjenjuje samo za tog poslovnog.partnera obično kupca)
CREATE TABLE IF NOT EXISTS nazivi_cjenika (  
  oznakaCjenika      VARCHAR(13) DEFAULT " ",
  primjenaCjenika    CHAR(1) DEFAULT NULL,
  nazivCjenika       VARCHAR(200) DEFAULT " ",  
  datumOtvaranja     DATETIME DEFAULT NULL,
  datumIzmjene       DATETIME DEFAULT 0,
  tkoJeIzmjenio      VARCHAR(40) DEFAULT " ", 
  PRIMARY KEY (oznakaCjenika) 
 ); 
-- primjenaCjenika
-- NULL ništa posebno
-- M primjena za sve maloprodaje
-- V primjena za sve veleprodaje 

