<?php
function get_predlosci($vrsta='0') {
    global $db;
    if(!($db instanceof PDO))
        return false;
    
    $query = "SELECT * FROM predlosci WHERE trim(vrsta)=trim(:vrsta) OR trim(:vrsta)='0'"; 
	try {
        $statement = $db->prepare($query);
        $statement->bindValue(':vrsta', $vrsta);
        $statement->execute();
        $result = $statement->fetchAll();
        $statement->closeCursor();
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

function get_predlosci_max_redniBroj($vrsta) {
    global $db;
    $query = "SELECT max(redniBroj) as redniBroj FROM predlosci WHERE trim(vrsta)=trim(:vrsta)"; 
	try {
        $statement = $db->prepare($query);
        $statement->bindValue(':vrsta', $vrsta);
        $statement->execute();
        $result = $statement->fetch();
        $statement->closeCursor();
        return $result[0];
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}
function get_predlozak($vrsta, $redniBroj) {
    global $db;
    $query = " 
        SELECT *
        FROM predlosci
        WHERE vrsta = :vrsta
        AND redniBroj = :redniBroj
        ";
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':vrsta', $vrsta);
        $statement->bindValue(':redniBroj', $redniBroj);
        $statement->execute();
        $result = $statement->fetch();
        $statement->closeCursor();
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}


function add_predlosci($vrsta, $redniBroj, $nazivPredloska, $predlozak) {
    global $db;
    $email_user = $_SESSION['admin']['email'];
    $query = "
        INSERT INTO predlosci
       (vrsta, redniBroj, nazivPredloska, predlozak, datumOtvaranja, tkoJeIzmjenio)
        VALUES
        (:vrsta, :redniBroj, :nazivPredloska, :predlozak, NOW(), :email_user )
        ";
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':vrsta', $vrsta);
        $statement->bindValue(':redniBroj', $redniBroj);
        $statement->bindValue(':nazivPredloska', $nazivPredloska);
        $statement->bindValue(':predlozak', $predlozak);
        $statement->bindValue(':email_user', $email_user);
        $statement->execute();
        $statement->closeCursor();
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

function update_predlosci($vrsta, $redniBroj, $nazivPredloska, $predlozak) {
    global $db;
    $email_user = $_SESSION['admin']['email'];
    $query = " 
        UPDATE predlosci
        SET nazivPredloska = :nazivPredloska,
            predlozak = :predlozak,
	    datumIzmjene = NOW(),
            tkoJeIzmjenio = :email_user
        WHERE vrsta = :vrsta
        AND redniBroj = :redniBroj
        ";
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':vrsta', $vrsta);
        $statement->bindValue(':redniBroj', $redniBroj);
        $statement->bindValue(':nazivPredloska', $nazivPredloska);
        $statement->bindValue(':predlozak', $predlozak);
        $statement->bindValue(':email_user', $email_user); 
        $statement->execute();
        $statement->closeCursor();
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

/*
 * Ako je redniBroj=0 briše sve predloške za navedenu vrstu, inače briše predložak s navedenim rednim brojem
 */
function delete_predlosci($vrsta, $redniBroj='') {
    global $db;
    $query = " 
        DELETE FROM predlosci 
        WHERE vrsta = :vrsta
        AND (redniBroj = :redniBroj OR :redniBroj='')
        ";
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':vrsta', $vrsta);
        $statement->bindValue(':redniBroj', $redniBroj);
        $statement->execute();
        $statement->closeCursor();
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

function obradaPredloska($naziv, $vrsta) {
    if(!isset($_REQUEST['rbPredloska_'.$naziv]))
        return 0;
    $redniBroj=$_REQUEST['rbPredloska_'.$naziv];
    if(!isset($_REQUEST['rbPredloska_'.$naziv]) || !isset($_REQUEST[$naziv])) 
        return 0;
    
    if($_REQUEST['redniBroj']==0) $_REQUEST['redniBroj'] = '';
    if(trim($_REQUEST['redniBroj'])!='') {
        $slogPredlosci = get_predlozak($vrsta, $_REQUEST['redniBroj']);
        if(isset($slogPredlosci['redniBroj']))
            $redniBroj = $slogPredlosci['redniBroj'];
    }
    if($redniBroj==0) {
        if(trim($_REQUEST[$naziv])!='') {
            if(trim($_REQUEST['redniBroj'])!='') {
                $redniBroj = (int)$_REQUEST['redniBroj'];
            }
            else {
                $redniBroj=get_predlosci_max_redniBroj($vrsta) + 1;
            }    
            add_predlosci($vrsta, $redniBroj, $_REQUEST['nazivPredloska'], $_REQUEST[$naziv]);
            $_REQUEST['rbPredloska_'.$naziv]=$redniBroj;
        }
    }
    else {
        if(isset($_REQUEST['brisiPredlozak']))
            delete_predlosci($vrsta, $redniBroj);
        else    
            update_predlosci($vrsta, $redniBroj, $_REQUEST['nazivPredloska'], $_REQUEST[$naziv]);
    }    
    
    return $redniBroj;
}

?>