<?php
function get_rabati($kodPartnera='',$kodGrupeRobe='') {
    global $db;
    $query = " 
        select r.* ,
        ifnull(rg.nazivGrupe, m.kodRobe) as naziv
        from rabati as r
        left outer join robne_grupe as rg on rg.kodgrupe=r.kodGrupeRobe
        left outer join maticna_robe as m on m.kodRobe=r.kodGrupeRobe
        WHERE (kodPartnera = :kodPartnera OR trim(:kodPartnera)='')
        AND (kodGrupeRobe=:kodGrupeRobe OR trim(:kodGrupeRobe)='')
        ";
	try {
        $statement = $db->prepare($query);
        $statement->bindValue(':kodPartnera', $kodPartnera);
        $statement->bindValue(':kodGrupeRobe', $kodGrupeRobe);
        $statement->execute();
        $result = $statement->fetchAll();
        $statement->closeCursor();
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}
function get_rabat($kodPartnera, $kodGrupeRobe='') {
    global $db;
    $query = " 
        select r.* ,
        ifnull(rg.nazivGrupe, m.kodRobe) as naziv
        from rabati as r
        left outer join robne_grupe as rg on rg.kodgrupe=r.kodGrupeRobe
        left outer join maticna_robe as m on m.kodRobe=r.kodGrupeRobe
        WHERE kodPartnera = :kodPartnera
        AND (kodGrupeRobe=:kodGrupeRobe or trim(:kodGrupeRobe)='')
        ";
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':kodPartnera', $kodPartnera);
        $statement->bindValue(':kodGrupeRobe', $kodGrupeRobe);
        $statement->execute();
        if($kodGrupeRobe=='')
            $result = $statement->fetchAll();
        else
            $result = $statement->fetch();
        $statement->closeCursor();
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

function add_rabati($slog) {
    global $db;
	$email_user = $_SESSION['admin']['email'];
    $query = 'INSERT INTO rabati
                 (kodPartnera, kodGrupeRobe, rabatPopust, datumOtvaranja, tkoJeIzmjenio)
              VALUES
                 (:kodPartnera, :kodGrupeRobe, :rabatPopust, NOW(), :email_user )
              ON DUPLICATE KEY UPDATE   
                rabatPopust = :rabatPopust,
                datumIzmjene = NOW(),
                tkoJeIzmjenio = :email_user
              ';
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':kodPartnera', $slog['kodPartnera']);
        $statement->bindValue(':kodGrupeRobe', $slog['kodGrupeRobe']);
        $statement->bindValue(':rabatPopust', $slog['rabatPopust']);
        $statement->bindValue(':email_user', $email_user);
        $statement->execute();
        $statement->closeCursor();
        return ;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

function update_rabati($slog) {
    global $db;
	$email_user = $_SESSION['admin']['email'];
    $query = " 
        UPDATE rabati
        SET rabatPopust = :rabatPopust,
            datumIzmjene = NOW(),
            tkoJeIzmjenio = :email_user
        WHERE kodPartnera = :kodPartnera
        AND kodGrupeRobe=:kodGrupeRobe
        ";
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':kodPartnera', $slog['kodPartnera']);
        $statement->bindValue(':kodGrupeRobe', $slog['kodGrupeRobe']);
        $statement->bindValue(':rabatPopust', $slog['rabatPopust']);
        $statement->bindValue(':email_user', $email_user); 
        $statement->execute();
        $statement->closeCursor();
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

function delete_rabati($kodPartnera, $kodGrupeRobe='') {
    global $db;
    $query = "
        DELETE FROM rabati
        WHERE kodPartnera = :kodPartnera
        AND (kodGrupeRobe=:kodGrupeRobe OR trim(:kodGrupeRobe)='')
        ";
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':kodPartnera', $kodPartnera);
        $statement->bindValue(':kodGrupeRobe', $kodGrupeRobe);
        $statement->execute();
        $statement->closeCursor();
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

function obrada_rabata_po_partneru($kodPartnera) {
    $n=count($_POST['grupeRoba']);
    for($i=0;$i<$n;$i++) {
        if(isset($_POST["brisanje_".$_POST["grupeRoba"][$i]]))
            delete_rabati ($kodPartnera, $_POST["grupeRoba"][$i]);
        else {
            if(isset($_POST['rabatGrupno']))
                if(trim($_POST['rabatGrupno'])!='' && (trim($_POST['grupaGrupno'])=='' || strpos($_POST["grupeRoba"][$i] ,$_POST['grupaGrupno'])===0 ))
                    $_POST["rabati"][$i]=$_POST['rabatGrupno'];
            $slog = array('kodPartnera' => $kodPartnera, 'kodGrupeRobe' => $_POST["grupeRoba"][$i],'rabatPopust' => $_POST["rabati"][$i]);
            add_rabati($slog);
        }
    }
}
function get_grupe_rabata($kodPartnera) {
    $rabati=get_rabat($kodPartnera);
    $grupe='';
    foreach ($rabati as $slog) {
        if(trim($grupe)!='')
            $grupe.=',';
        $grupe.=$slog['kodGrupeRobe'];
    }
    return $grupe;
}

function postavi_rabat($vrsDo, $zapis, $kodPartnera, $kodGrupe, $rabatPopust) {
    include_once 'model/vrste_dokumenata_db.php';
    $slogVrsDo=get_vrsta_dokumenta($vrsDo);
    if (($slogVrsDo['azurStanja']!=1 && trim($vrsDo)!='6' || trim($vrsDo)=='3' && trim($zapis)=='K2')) {
        $rabatPoPartneru=get_rabat($kodPartnera, $kodGrupe);
        if(isset($rabatPoPartneru['rabatPopust'])) {
            if($rabatPoPartneru['rabatPopust']!=0) 
                $rabatPopust = $rabatPoPartneru['rabatPopust'];
        }    
    }    
    return $rabatPopust;
}    
?>