<?php
function kreiraj_slog_tablice($tablica) {
    $struktura=get_struktura_tablice($tablica);
    $slog=array();
    foreach ($struktura as $kolona) {
        if($kolona['COLUMN_NAME']!='datumOtvaranja' && $kolona['COLUMN_NAME']!='tkoJeIzmjenio' && $kolona['COLUMN_NAME']!='datumIzmjene'  && $kolona['COLUMN_NAME']!='datumZakljucavanja') {
            if(trim($kolona['COLUMN_DEFAULT'])!='' && $kolona['COLUMN_DEFAULT']!='NULL') //kolona ima defaault vrijednost
                if($kolona['NUMERIC_PRECISION']>0) //kolona je numerička
                    if($kolona['NUMERIC_SCALE']>0) //kolona je flost
                        $slog[$kolona['COLUMN_NAME']]=floatval($kolona['COLUMN_DEFAULT']);
                    else //kolona je int
                        $slog[$kolona['COLUMN_NAME']]=intval($kolona['COLUMN_DEFAULT']);
                else
                    $slog[$kolona['COLUMN_NAME']]= str_replace("'", '', $kolona['COLUMN_DEFAULT']);
            else if($kolona['IS_NULLABLE']=='NO' && $kolona['NUMERIC_PRECISION']>0) //kolona je numerička i obavezna, stavljamo 0
                $slog[$kolona['COLUMN_NAME']]=0;
            else
                $slog[$kolona['COLUMN_NAME']]='';
        }
    }
    return $slog;
}

function get_struktura_tablice($tablica) {
    global $db;
    $query = " 
        select * 
        from information_schema.`COLUMNS`
        where table_schema=database() and table_name = :tablica
        ";
	try {
        $statement = $db->prepare($query);
        $statement->bindValue(':tablica', $tablica);
        $statement->execute();
        $result = $statement->fetchAll();
        $statement->closeCursor();
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

function get_primarni_kljuc($tablica) {
    global $db;
    $query = " 
        select COLUMN_NAME as naziv
        from information_schema.`COLUMNS`
        where table_schema=database() and table_name = :tablica and COLUMN_KEY='PRI'
        ";
	try {
        $statement = $db->prepare($query);
        $statement->bindValue(':tablica', $tablica);
        $statement->execute();
        $r = $statement->fetchAll();
        $statement->closeCursor();
        $result = array();
        foreach ($r as $kolona) 
            $result[]=$kolona['naziv'];
        
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

/*
 * f-ja vraća jedan slog iz tablice,
 * isto kao get_partner($kodPartnera);
 */
function get_slog_tablice($tablica, $slog, $poljaKljuca=null) {
    global $db;
    if(!isset($poljaKljuca))
        $poljaKljuca=get_primarni_kljuc($tablica);
    $query = " 
        SELECT *
        FROM $tablica   
        ";     
    $query.=sastavi_where_dio_od_kljuca($poljaKljuca);
    try {
        $struktura=  get_struktura_tablice($tablica);
        $statement = $db->prepare($query);
        foreach ($poljaKljuca as $nazivPolja) {
            $strukturaPolja=get_strukturu_polja($nazivPolja, $struktura); //uzima strukturu polja
            postavi_parametar($statement, $nazivPolja, $strukturaPolja['DATA_TYPE'], $strukturaPolja['IS_NULLABLE'], $slog[$nazivPolja]);
        }

        //$statement->bindValue(':kodRadnika', $kodRadnka);
        $statement->execute();
        $result = $statement->fetch();
        $statement->closeCursor();
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
    
}

function delete_slog_tablice($tablica, $slog, $poljaKljuca=null) {
    global $db;
    if(!isset($poljaKljuca))
        $poljaKljuca=get_primarni_kljuc($tablica);
    $query = "DELETE FROM $tablica \n";
     
    $query.=sastavi_where_dio_od_kljuca($poljaKljuca);
    try {
        $struktura=  get_struktura_tablice($tablica);
        $statement = $db->prepare($query);
        foreach ($poljaKljuca as $nazivPolja) {
            $strukturaPolja=get_strukturu_polja($nazivPolja, $struktura); //uzima strukturu polja
            //postavlja paramtar
            postavi_parametar($statement, $nazivPolja, $strukturaPolja['DATA_TYPE'], $strukturaPolja['IS_NULLABLE'], $slog[$nazivPolja]);
        }

        $statement->execute();

        $statement->closeCursor();
        return ;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
    
}

function get_tablica($tablica) {
    global $db;
    if(!isset($poljaKljuca))
        $poljaKljuca=get_primarni_kljuc($tablica);
    $query = "SELECT * FROM $tablica ";
    try {
        $statement = $db->prepare($query);
        $statement->execute();
        $result = $statement->fetchAll();
        $statement->closeCursor();
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
    
}

// kreira where dio sql upita od polja primarnog ključa npr. "WHERE kodRadnika=:kodRadnika"
function sastavi_where_dio_od_kljuca($poljaKljuca, $daliStaro=false) {
    // za update u where dio idu stare vrijednosti ključa
    $prefiks=$daliStaro?'staro_':'';
    $whereDio='WHERE ';
    foreach ($poljaKljuca as $polje) {
        if($whereDio!='WHERE ')
            //dodaje AND  ako ima više polja
            $whereDio.=' AND ';
        $whereDio.="$polje=:$prefiks$polje \n";
    }
    return $whereDio;
}
/*
 * f-ja postalja jedan parametar  u  sql upitu
 * Parametri:
 * &$statement - PDO statement za koju postavljamo parametar & - (prametar by address) znači da se sve promjene zapamte i izvan funkcije, 
 * $nazivPolja - naziv polja, 
 * $tipPolja - tip poljs, CHAR, VARCHAR, DECIMAL, DATETIME,... , 
 * $dozvoljavaNull - 'YES' polje može biti null, 'NO' pole ne može biti null, 
 * $vrijednost - vrijednost koju postavljamo u pametar
 */
function postavi_parametar(&$statement, $nazivPolja, $tipPolja, $dozvoljavaNull, $vrijednost) {
   if($dozvoljavaNull=='YES' && $vrijednost=='') {
        $statement->bindValue(":$nazivPolja", null, PDO::PARAM_NULL);   
        return;
   }
   
   switch (strtoupper($tipPolja)) {
       case 'DATE':
       case 'DATETIME':
       case 'TIMESTAMP':
           if(strtoupper($tipPolja)=='DATE')
               $formatDatuma='Y-m-d';
           else
               $formatDatuma='Y-m-d H:i:s';
           $d1=new DateTime($vrijednost);
           $vrijednost = $d1->format($formatDatuma);

           break;

       case 'DECIMAL':
       case 'NUMERIC':
       case 'FLOAT':
       case 'DOUBLE':
           $vrijednost=str_replace(',', '.', $vrijednost);
           break;
   }
   $statement->bindValue(":$nazivPolja", $vrijednost);
        
}

/*
 *  vrača strukturu polja
 *  Parametri:
 *  $nazivPolja - naziv polja za koju vraća strukturu
 *  $struktura - struktura cijele tablice (svih polja)
 */
function get_strukturu_polja($nazivPolja, $struktura) {
    foreach ($struktura as $kolona) {
        if($kolona['COLUMN_NAME']==$nazivPolja)
            return $kolona;
    }
    return false;
}

function add_slog_tablice($tablica, $slog) {
    global $db;
    $email_user = $_SESSION['admin']['email'];
    $struktura  = get_struktura_tablice($tablica);
    $query = "INSERT INTO $tablica ";
    $dioPolja=$dioParametri='';
    foreach ($struktura as $strukturaPolja) {
        if(isset($slog[$strukturaPolja['COLUMN_NAME']])) {
            $dioPolja.=$strukturaPolja['COLUMN_NAME'].",\n";
            $dioParametri.=':'.$strukturaPolja['COLUMN_NAME'].",\n";
        }
    }
    $dioPolja.="datumOtvaranja, \ntkoJeIzmjenio \n";
    $dioParametri.="NOW(), \n:email_user \n";
    $query.="( \n".$dioPolja."\n)\n VALUES ( \n".$dioParametri."\n)\n";

    try {
        $statement = $db->prepare($query);
        foreach ($struktura as $strukturaPolja) {
            if(isset($slog[$strukturaPolja['COLUMN_NAME']])) {
                postavi_parametar($statement, $strukturaPolja['COLUMN_NAME'], $strukturaPolja['DATA_TYPE'], $strukturaPolja['IS_NULLABLE'], $slog[$strukturaPolja['COLUMN_NAME']]);
            }
        }

        $statement->bindValue(':email_user', $email_user);
        $statement->execute();
        $statement->closeCursor();
        //return $poreznaGrupa;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
        
}

function update_slog_tablice($tablica, $slog, $poljaKljuca=null) {
    global $db;
    if(!isset($poljaKljuca))
        $poljaKljuca=get_primarni_kljuc($tablica);
    
    $email_user = $_SESSION['admin']['email'];
    $struktura  = get_struktura_tablice($tablica);
    $query = "UPDATE $tablica \nSET\n";
    $dioPolja='';
    foreach ($struktura as $strukturaPolja) {
        if(isset($slog[$strukturaPolja['COLUMN_NAME']])) {
            $dioPolja.=$strukturaPolja['COLUMN_NAME']."=:".$strukturaPolja['COLUMN_NAME'].",\n";
        }
    }
    $dioPolja.="datumIzmjene = NOW(), \n"."tkoJeIzmjenio = :email_user\n";
    $query.=$dioPolja.sastavi_where_dio_od_kljuca($poljaKljuca, isset($_REQUEST['stariKljuc']));

    try {
        $statement = $db->prepare($query);
        foreach ($struktura as $strukturaPolja) {
            if(isset($slog[$strukturaPolja['COLUMN_NAME']])) {
                postavi_parametar($statement, $strukturaPolja['COLUMN_NAME'], $strukturaPolja['DATA_TYPE'], $strukturaPolja['IS_NULLABLE'], $slog[$strukturaPolja['COLUMN_NAME']]);
            }
        }

        if(isset($_REQUEST['stariKljuc'])) {
            foreach ($poljaKljuca as $polje) {
                $strukturaPolja=  get_strukturu_polja($polje, $struktura);
                postavi_parametar($statement, 'staro_'.$polje, $strukturaPolja['DATA_TYPE'], $strukturaPolja['IS_NULLABLE'], $_REQUEST['stariKljuc'][$polje]);
           }
           
        }
        $statement->bindValue(':email_user', $email_user);
        $statement->execute();
        $statement->closeCursor();
        //return $poreznaGrupa;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
        
}

function kljucUHidden($tablica, $slog, $poljaKljuca=null) {
    $hidden='';
    if(!isset($poljaKljuca))
        $poljaKljuca=get_primarni_kljuc($tablica);
    foreach ($poljaKljuca as $polje) {
        $hidden.='<input type="hidden" name="stariKljuc['.$polje.']" value="'.$slog[$polje].'" />';
   }
   return $hidden;
}    
?>